metapho.main.MetaPhoWindow

Package metapho :: Module main :: Class MetaPhoWindow |
[hide private]

# Class MetaPhoWindow

source code

    object --+
             |
            MetaPhoWindow

The main controller window for metapho. This holds any child widgets, like the image viewer and tags window, and manages key events and other user commands.

Instance Methods | [hide private]
__init__(self, file_list) x.__init__(...) initializes x; see help(type(x)) for signature | source code
quit(self, widget=None, data=None) | source code
read_all_tags(self) Read tags in all directories used by images in argv. | source code
first_image(self) | source code
lastImage(self) | source code
next_image(self) Advance to the next image, if possible. | source code
prev_image(self) | source code
delete_confirm(self) Ask the user whether to really delete an image. | source code
key_press_event(self, widget, event) Handle a key press event anywhere in the window | source code
isearch_key_press(self, widget, event) Handle key presses when we're in isearch mode, typing in a search pattern. | source code
main(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, file_list) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### next_image(self) | source code
Advance to the next image, if possible. Tell the viewer to load and show the image.

### delete_confirm(self) | source code
Ask the user whether to really delete an image. Return True for yes, False for no. Accept some keystrokes beyond the usual ones, e.g. d or ctrl-d confirms the delete.